@@ -22,7 +22,9 @@
 #ifndef  _CGIPAF_DEFS_H
 #define  _CGIPAF_DEFS_H
 
-#include "config.h"
+#include "common.h"
+#include "run_cmd.h"
+#include "acl.h"
 
 #ifndef  _WITHPAM
 #include "fgetpwnam.h"
