@@ -1,7 +1,7 @@
 /*
  * cgipaf_func.c
  *
- * Copyright (C) 2003 Staf Wagemakers Belgie/Belgium
+ * Copyright (C) 2003,2006 Staf Wagemakers Belgie/Belgium
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
  */
 
 #include "cgipaf_func.h"
+#include "write_log.h"
 
 char *** add_post_2_string_pair ( WEBDATA *data, char *** ret ) {
 
@@ -30,30 +31,57 @@ char *** add_post_2_string_pair ( WEBDATA *data, char *** ret ) {
 
 	int i;
 
+	write_log(LOG_USER,7,"cgipaf_func.c: add_post_2_string_pair started...");
+
 	if(data==NULL)  return ret;
 
+	write_log(LOG_USER,7,"cgipaf_func.c: parse post data loop started...");
 
-	for (i=0;i<data->n;i++) {
+	if (data->name != NULL ) {
 
-		if (data->name[i]) { 
+		for (i=0;i<data->n;i++) {
 
-			c=xmalloc(strlen(txt_post1)+strlen(data->name[i])+strlen(txt_post2)+1);
+			write_log(LOG_USER,7,"cgipaf_func.c: loop counter %d/%d...",i,data->n);
 
-			strcpy(c,txt_post1);
-			strcat(c,data->name[i]);
-			strcat(c,txt_post2);
+			if (data->name[i]!=NULL) { 
 
-			ret=add_2_string_pair(ret,c,data->value[i]); 
+				write_log(LOG_USER,7,"cgipaf_func.c: processing %s...",data->name[i]);
 
-		}  
+				c=xmalloc(strlen(txt_post1)+strlen(data->name[i])+strlen(txt_post2)+1);
 
+				strcpy(c,txt_post1);
+				strcat(c,data->name[i]);
+				strcat(c,txt_post2);
+
+				write_log(LOG_USER,7,"cgipaf_func.c: adding %s to _POST array...",c);
+
+				ret=add_2_string_pair(ret,c,data->value[i]); 
+
+				write_log(LOG_USER,7,"cgipaf_func.c: _POST[%s] assigned ...",c);
+
+			}
+
+			write_log(LOG_USER,7,"cgipaf_func.c: loop ends counter = %d...",i);
+
+
+		}
 
 	}
+	else {
+
+		write_log(LOG_USER,7,"cgipaf_func.c: post array seems to empty...");
+
+	}
+
+	write_log(LOG_USER,7,"cgipaf_func.c: parse post data loop ends...");
+
 	c=xmalloc(strlen(txt_poststring)+1);
 	strcpy(c,txt_poststring);
 
 	ret=add_2_string_pair(ret,c,data->string);
 
+	write_log(LOG_USER,7,"cgipaf_func.c: add_post_2_string_pair ends...");
+
 	return(ret);
 
 }
