@@ -1,7 +1,7 @@
 /*
  * mailcfg.c
  *
- * Copyright (C) 1999,2001-03 Staf Wagemakers Belgie/Belgium
+ * Copyright (C) 1999,2001,2002,2003,2007 Staf Wagemakers Belgie/Belgium
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
  *
  */
 
+#include "cgipaf_defs.h"
 #define  FORWARD               "forward"
 #define  FORWARD_TO            "forward_to"
 #define  AUTOREPLY             "autoreply"
@@ -27,8 +28,8 @@
 #define  DOTFORWARD            ".forward"
 #define  KEEP_MSG              "keep_msg"
 #define  SENDMAIL              "sendmail"
+#define  FORMAIL               "formail"
 #define  CFGDOMAIN             "domain"
-#include "cgipaf_defs.h"
 
 char txt_yes[]="yes";
 char txt_no[]="no";
@@ -49,7 +50,7 @@ void yes_no(char *test,char *name,char *not_name,int *state)
    }
 }
 
-main()
+int main()
 {
    int    forward_state=0;
    int    keep_state=0;
@@ -59,11 +60,16 @@ main()
    int 	  mailcfg_check=1;
    char   *c=NULL;
    char   *sendmail=NULL;
+   char   *formail=NULL;
    char   *domain=NULL;
    char   txt_sendmail[]="/usr/lib/sendmail";
+   char   txt_formail[]="formail";
    FILE   *fp;
    WEBDATA *cookies;
 #include "cgipaf_vars.h"
+
+   write_log(LOG_USER,7,"mailcfg.c started");
+
 #include "cgipaf_init.c"
 
 
@@ -313,9 +319,11 @@ main()
 
       /* get the previous mailcfg state out the user's .cgipaf_state file */
       
+   	write_log(LOG_USER,7,"mailcfg_check is enabled, vrfing current state");
+
       if ((oldstate=get_mailcfg_status(pw))==-1) 
          write_log(LOG_USER,7,
-		 "failed to read old status file .cgipaf_state: %s for user %s",strerror(errno));
+		 "failed to read old status file .cgipaf_state: %s for user %s",strerror(errno),name);
    
       /* calculate the new state */
    
@@ -410,7 +418,7 @@ main()
       /* if auto replay if enabled create a new .procmailrc */
       
       if(!strcmp(autoreply,txt_yes)||!strcmp(forward,txt_yes)) {
-	 if(write_procmailrchead(pw,sendmail)==-1) {
+	 if(write_procmailrchead(pw,sendmail,formail)==-1) {
 	    write_log(LOG_USER,1,"%s write_procmailrchead() failed",err_updateprocmailrc);
 	    show_msg_and_exit(config_file,doc_root,CFGSECTION,ERR_UPDATEPROCMAILRC,err_updateprocmailrc,options,txt_message);
 	 }
@@ -489,4 +497,6 @@ main()
    }
 
    if(config_file!=NULL) fclose(config_file);
+	
+   return(0);
 }
