@@ -1,7 +1,7 @@
 /*
  * passpam.c
  *
- * Copyright (C) 2000-02 Staf Wagemakers Belgie/Belgium
+ * Copyright (C) 2001,2002,2007 Staf Wagemakers Belgie/Belgium
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,8 @@ static int chauth_flag=0;
 char passwd_service[]="passwd";
 int  set_pam_chauth_flag (int flag) {
      chauth_flag=flag;
+
+     return (chauth_flag);
 }
 
 char * set_pam_service(char *s)
@@ -45,11 +47,19 @@ char *last_pam_msg()
 return(pam_msg);   
 }
 
+#ifdef SOLARISHOST
+int chpasswd(int num_msg, struct pam_message **msg,
+    	     struct pam_response **resp, void *appdata_ptr)
+#else
+
 int chpasswd(num_msg, msg, resp, appdata_ptr)
     int          num_msg;
     const struct pam_message **msg;
     struct       pam_response **resp;
     void         *appdata_ptr;
+
+#endif
+
 {
     int i;
     struct pam_response *rp = xmalloc(sizeof(struct pam_response) * num_msg);
@@ -83,9 +93,10 @@ int chpasswd(num_msg, msg, resp, appdata_ptr)
 }
 
 static struct pam_conv conv = {
-	chpasswd, 
+        chpasswd, 
 	NULL
 };
+
 /* ---------------------------------------------- */
 /* reads the passwd info out /etc/passwd and      */
 /* /etc/shadow                                    */
