@@ -39,10 +39,11 @@
 
 # define __XMALLOC_H
 
-void *set_memerr(void *s);
+void (*set_memerr(void (*s)()))();
 void *xmalloc (size_t size);
 void *xrealloc (void *ptr, size_t size);
 void *xcalloc (size_t n, size_t size);
 void xfree(void *ptr);
+void xmalloc_out_of_memory();
 
 #endif
